@@ -40,6 +40,7 @@
 #include "executor/spi.h"
 #include "foreign/fdwapi.h"
 #include "foreign/foreign.h"
+#include "mb/pg_wchar.h"
 #include "nodes/execnodes.h"
 #include "nodes/extensible.h"
 #include "nodes/makefuncs.h"
@@ -76,6 +77,7 @@
 #include "tcop/utility.h"
 #include "utils/builtins.h"
 #include "utils/date.h"
+#include "utils/datetime.h"
 #include "utils/float.h"
 #include "utils/geo_decls.h"
 #include "utils/guc.h"
